// $Id: runfig.cxx,v 1.2 2006/11/20 12:39:29 loreti Exp $

class LinFit {                  // Computes x/y over a line
private:                        //   representing a linear fit
  Double_t A;                   //     and given as y = A + B * x
  Double_t B;
public:
  LinFit(Double_t a, Double_t b) : A(a), B(b) {}
  Double_t GetY(Double_t x) const { return A + B * x; }
  Double_t GetX(Double_t y) const { return (y - A) / B; }
};

void runfig() {

  gROOT->Reset();               // Setup generale
  gROOT->Clear();
  gROOT->SetStyle("Plain");
  gStyle->SetOptStat(10);
  gStyle->SetOptStat(111111);

  const Int_t N = 12;

  Double_t x[N];
  for (Int_t i = 0;  i < N;  ++i) x[i] = i+1;
  
  const Double_t y[N] = {
    2.0, 2.2, 2.4, 2.4, 2.8, 3.2,
    3.6, 4.4, 5.2, 6.0, 7.0, 7.6
  };

  Double_t e[N];
  for (Int_t i = 0;  i < N;  ++i) e[i] = 0.5;

  LinFit fit(0.675758, 0.521678);

  const Int_t Npixels =  600;
  const Int_t Npoints = 1000;

  Double_t Lo_x = 0.0, Lo_y = 0.0, Hi_x = 13.0, Hi_y = 9.0;

  TCanvas *c = new TCanvas("c", "Esempio", Npixels, Npixels);
  c->SetBorderMode(0);
  c->SetBorderSize(2);
  c->SetFrameBorderMode(0);
  c->SetFrameBorderSize(2);
  c->SetGrid();
  c->DrawFrame(Lo_x, Lo_y, Hi_x, Hi_y);

  TH1F *h = new TH1F("h", "", Npoints, Lo_x, Hi_x);
  h->SetMinimum(Lo_y);
  h->SetMaximum(Hi_y);
  h->SetStats(0);

  TAxis *ax = h->GetXaxis();
  ax->SetNdivisions(20207, kTRUE);
  ax->SetLabelSize(0.035);
  ax->SetLabelOffset(0.01);
  ax->SetLabelFont(132);

  ax = h->GetYaxis();
  ax->SetNdivisions(509);
  ax->SetLabelSize(0.035);
  ax->SetLabelOffset(0.01);
  ax->SetLabelFont(132);

  TGraph *g = new TGraphErrors(N, x, y, 0, e);
  g->SetMarkerStyle(20);
  g->SetMarkerSize(0.9);

  TLine *l = new TLine(Lo_x, fit.GetY(Lo_x), Hi_x, fit.GetY(Hi_x));

  h->Draw();
  l->Draw("same");
  g->Draw("P");
  c->Update();
  c->SaveAs("runfig.eps");
}
